@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -263,6 +263,24 @@ public class ParticipantTools {
         }
     }
 
+    /**
+     * Gets the personal alarm setting from an appointment.
+     *
+     * @param appointment The appointment
+     * @param userID The ID of the user to get the reminder time for
+     * @return The reminder minutes, or <code>-1</code> if not set
+     */
+    public static int getReminderMinutes(Appointment appointment, int userID) {
+        if (null != appointment && null != appointment.getUsers()) {
+            for (UserParticipant user : appointment.getUsers()) {
+                if (user.getIdentifier() == userID) {
+                    return user.containsAlarm() ? user.getAlarmMinutes() : -1;
+                }
+            }
+        }
+        return -1;
+    }
+
     private ParticipantTools() {
         super();
     }
