@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -142,7 +142,7 @@ public class SyncCollection extends WebdavPropfindAction {
 
     private String getSyncToken(final WebdavRequest req, final Document requestBody) throws WebdavProtocolException {
 
-        final List<Element> children = requestBody.getRootElement().getChildren("sync-token", DAV_NS);
+        final List<Element> children = null == requestBody ? null : requestBody.getRootElement().getChildren("sync-token", DAV_NS);
         if (children == null || children.isEmpty()) {
             return null;
         }
