@@ -255,6 +255,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                 /*
                  * update exception
                  */
+                // TODO fix for bug 32536 - closing reminder for appointment results in 'containing changes'
                 if (null != originalException && false == containsChanges(originalException, exceptionToSave)) {
                     LOG.debug("No changes detected in {}, skipping update.", exceptionToSave);
                 } else {
@@ -357,9 +358,12 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
             CalendarDataObject appointment = parent.load(object, true);
             CalendarDataObject[] changeExceptions = 0 < object.getRecurrenceID() ? parent.getChangeExceptions(object.getObjectID()) : null;
             /*
-             * transform change- to delete-exceptions where user is removed from participants if needed (bug #26293)
+             * load change exceptions, transforming them to delete-exceptions where user is removed from participants if needed (bug #26293)
              */
             if (null != changeExceptions && 0 < changeExceptions.length) {
+                for (int i = 0; i < changeExceptions.length; i++) {
+                    changeExceptions[i] = parent.load(changeExceptions[i], true);
+                }
                 changeExceptions = Patches.Outgoing.setDeleteExceptionForRemovedParticipant(factory, appointment, changeExceptions);
             }
             /*
@@ -371,8 +375,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
              */
             if (null != changeExceptions && 0 < changeExceptions.length) {
                 for (Appointment changeException : changeExceptions) {
-                    icalEmitter.writeAppointment(session, parent.load(changeException, true),
-                        factory.getContext(), conversionErrors, conversionWarnings);
+                    icalEmitter.writeAppointment(session, changeException, factory.getContext(), conversionErrors, conversionWarnings);
                 }
             }
             ByteArrayOutputStream bytes = new ByteArrayOutputStream();
@@ -454,7 +457,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
          * parse appointments
          */
         return factory.getIcalParser().parseAppointments(
-                patchedICal, getTimeZone(), factory.getContext(), new ArrayList<ConversionError>(), new ArrayList<ConversionWarning>());
+            patchedICal, getTimeZone(), factory.getContext(), new ArrayList<ConversionError>(), new ArrayList<ConversionWarning>());
     }
 
     private static boolean differs(Object value1, Object value2) {
@@ -477,8 +480,8 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
 
     private static boolean differs(int field, Appointment oldAppointment, CalendarDataObject cdo) {
         return oldAppointment.contains(field) && false == cdo.contains(field) ||
-                false == oldAppointment.contains(field) && cdo.contains(field) ||
-                differs(oldAppointment.get(field), cdo.get(field));
+            false == oldAppointment.contains(field) && cdo.contains(field) ||
+            differs(oldAppointment.get(field), cdo.get(field));
     }
 
     private static boolean containsChanges(Appointment oldAppointment, CalendarDataObject cdo) {
@@ -500,7 +503,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                 }
             }
             if (CalendarObject.NO_RECURRENCE != oldAppointment.getRecurrenceType() &&
-                    CalendarObject.NO_RECURRENCE != cdo.getRecurrenceType()) {
+                CalendarObject.NO_RECURRENCE != cdo.getRecurrenceType()) {
                 for (int field : RECURRENCE_FIELDS) {
                     if (differs(field, oldAppointment, cdo)) {
                         return true;
@@ -533,7 +536,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
          * reset previously set recurrence specific fields
          */
         if (CalendarObject.NO_RECURRENCE != oldAppointment.getRecurrenceType() &&
-                CalendarObject.NO_RECURRENCE != updatedAppointment.getRecurrenceType()) {
+            CalendarObject.NO_RECURRENCE != updatedAppointment.getRecurrenceType()) {
             for (int field : RECURRENCE_FIELDS) {
                 if (oldAppointment.contains(field) && false == updatedAppointment.contains(field)) {
                     if (CalendarObject.UNTIL == field) {
